@@ -4,12 +4,17 @@
 
 import itertools
 import unittest
-from typing import ClassVar, Collection, Optional
+from typing import ClassVar, Collection, Optional, Sequence
 
 import click
 from click.testing import CliRunner, Result
 
-from class_resolver import Resolver, UnexpectedKeywordError
+from class_resolver import (
+    RegistrationNameConflict,
+    RegistrationSynonymConflict,
+    Resolver,
+    UnexpectedKeywordError,
+)
 
 try:
     import ray.tune as tune
@@ -92,6 +97,14 @@ class TestResolver(unittest.TestCase):
             self.resolver.lookup(3)
         self.assertEqual(self.resolver.lookup(A(name="max")), A)
 
+    def test_lookup_no_synonyms(self):
+        """Test looking up classes without auto-synonym."""
+        resolver = Resolver([A], base=Base, synonym_attribute=None)
+        self.assertEqual(A, resolver.lookup("a"))
+        self.assertEqual(A, resolver.lookup("A"))
+        with self.assertRaises(KeyError):
+            self.assertEqual(A, resolver.lookup("a_synonym_1"))
+
     def test_passthrough(self):
         """Test instances are passed through unmodified."""
         a = A(name="charlie")
@@ -110,6 +123,12 @@ class TestResolver(unittest.TestCase):
         self.assertIsNone(self.resolver.make_safe(None))
         self.assertIsNone(Resolver.from_subclasses(Base, default=A).make_safe(None))
 
+        name = "charlie"
+        # Test instantiating with positional dict into kwargs
+        self.assertEqual(A(name=name), self.resolver.make_safe("a", {"name": name}))
+        # Test instantiating with kwargs
+        self.assertEqual(A(name=name), self.resolver.make_safe("a", name=name))
+
     def test_registration_synonym(self):
         """Test failure of registration."""
         self.assertNotIn(D, self.resolver.lookup_dict.values())
@@ -117,18 +136,39 @@ class TestResolver(unittest.TestCase):
         name = "charlie"
         self.assertEqual(D(name=name), self.resolver.make("d", name=name))
 
-    def test_registration_synonym_failure(self):
+    def test_registration_empty_synonym_failure(self):
         """Test failure of registration."""
         self.assertNotIn(D, self.resolver.lookup_dict.values())
         with self.assertRaises(ValueError):
             self.resolver.register(D, synonyms={""})
 
-    def test_registration_failure(self):
+    def test_registration_name_failure(self):
         """Test failure of registration."""
-        with self.assertRaises(KeyError):
+        with self.assertRaises(RegistrationNameConflict) as e:
             self.resolver.register(A)
-        with self.assertRaises(KeyError):
+        self.assertEqual("name", e.exception.label)
+        self.assertIn("name", str(e.exception))
+        with self.assertRaises(RegistrationNameConflict) as e:
             self.resolver.register(D, synonyms={"a"})
+        self.assertEqual("synonym", e.exception.label)
+        self.assertIn("synonym", str(e.exception))
+
+    def test_registration_synonym_failure(self):
+        """Test failure of registration."""
+        resolver = Resolver([], base=Base)
+        resolver.register(A, synonyms={"B"})
+        with self.assertRaises(RegistrationSynonymConflict) as e:
+            resolver.register(B)
+        self.assertEqual("name", e.exception.label)
+        self.assertIn("name", str(e.exception))
+
+        class F(Base):
+            """Extra class for testing."""
+
+        with self.assertRaises(RegistrationSynonymConflict) as e:
+            resolver.register(F, synonyms={"B"})
+        self.assertEqual("synonym", e.exception.label)
+        self.assertIn("synonym", str(e.exception))
 
     def test_make_from_kwargs(self):
         """Test making classes from kwargs."""
@@ -207,6 +247,33 @@ class TestResolver(unittest.TestCase):
 
         self._test_cli(cli)
 
+    def test_click_option_default(self):
+        """Test generating an option with a default."""
+        resolver = Resolver([A, B, C, E], base=Base, default=A)
+
+        @click.command()
+        @resolver.get_option("--opt", as_string=True)
+        def cli(opt):
+            """Run the test CLI."""
+            self.assertIsInstance(opt, str)
+            click.echo(self.resolver.lookup(opt).__name__, nl=False)
+
+        self._test_cli(cli)
+
+    def test_click_option_multiple(self):
+        """Test the click option with multiple arguments."""
+
+        @click.command()
+        @self.resolver.get_option("--opt", default="a", as_string=True, multiple=True)
+        def cli(opt):
+            """Run the test CLI."""
+            self.assertIsInstance(opt, Sequence)
+            for opt_ in opt:
+                self.assertIsInstance(opt_, str)
+                click.echo(self.resolver.lookup(opt_).__name__, nl=False)
+
+        self._test_cli(cli)
+
     def test_signature(self):
         """Check signature tests."""
         self.assertTrue(self.resolver.supports_argument("A", "name"))
@@ -219,6 +286,27 @@ class TestResolver(unittest.TestCase):
             resolver.make("A", nope="nopppeeee")
             self.assertEqual("AAltBase did not expect any keyword arguments", str(e))
 
+    def test_base_suffix(self):
+        """Check that the unexpected keyword error is thrown properly."""
+        resolver = Resolver.from_subclasses(AltBase, suffix=None, base_as_suffix=True)
+        self.assertEqual(AAltBase, resolver.lookup("AAltBase"))
+        self.assertEqual(AAltBase, resolver.lookup("A"))
+
+        resolver = Resolver.from_subclasses(AltBase, suffix="nope", base_as_suffix=True)
+        self.assertEqual(AAltBase, resolver.lookup("AAltBase"))
+        with self.assertRaises(KeyError):
+            resolver.lookup("A")
+
+        resolver = Resolver.from_subclasses(AltBase, suffix="")
+        self.assertEqual(AAltBase, resolver.lookup("AAltBase"))
+        with self.assertRaises(KeyError):
+            resolver.lookup("A")
+
+        resolver = Resolver.from_subclasses(AltBase, base_as_suffix=False)
+        self.assertEqual(AAltBase, resolver.lookup("AAltBase"))
+        with self.assertRaises(KeyError):
+            resolver.lookup("A")
+
     def test_make_many(self):
         """Test the make_many function."""
         with self.assertRaises(ValueError):
